
%ifarch aarch64
# Work around gcc bug causing Error: can't resolve value for symbol `.LVU45'
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

%bcond_with ffmpeg

Name:		vice
Version:	3.8
Release:	%mkrel 2
License:	GPLv2+
Summary:	Versatile Commodore Emulator
Group:		Emulators
URL:		https://vice-emu.sourceforge.io/
Source0:	https://downloads.sourceforge.net/project/vice-emu/releases/vice-%{version}.tar.gz
Source1:	vice-normalicons.tar.bz2
Source2:	vice-largeicons.tar.bz2
Source3:	vice-miniicons.tar.bz2
Patch1:		vice-build-flags.patch
BuildRequires:	bdftopcf
BuildRequires:	bison
BuildRequires:	dos2unix
BuildRequires:	flex
BuildRequires:	gettext-devel
BuildRequires:	giflib-devel
BuildRequires:	gtkglext-devel
BuildRequires:	ieee1284-devel
BuildRequires:	liblame-devel
BuildRequires:	mkfontdir
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(flac)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-3.0)
%if %{with ffmpeg}
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
%endif
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(xf86vidmodeproto)
BuildRequires:	pkgconfig(xt)
BuildRequires:	readline-devel
BuildRequires:	texinfo
BuildRequires:	texinfo-tex
BuildRequires:	xa

%description
VICE is a set of accurate emulators for the Commodore 64, 128, VIC20,
PET and CBM-II 8-bit computers, all of which run under the X Window
System.

%prep
%autosetup -p1

# use system libs
rm -rf src/lib/{liblame,libx264}

%if %{with ffmpeg} || 1
rm -rf src/lib/{ffmpeg,libffmpeg}
sed -i -e '/src\/lib\/ffmpeg\/Makefile/d' configure.ac
%endif

%build
./autogen.sh
%configure \
%if %{with ffmpeg}
  --enable-external-ffmpeg \
%endif
  --enable-gtk3ui \
  --with-lame \
  --enable-ethernet \
  --with-libieee1284 \
  --without-portaudio \
  --without-oss
  
%make_build

%install
%make_install

#xdg menu
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/vice-x64.desktop << EOF
[Desktop Entry]
Name=C64 Emulator
Comment=Commodore 64 sc Emulator
Exec=%{_bindir}/x64sc %U
Icon=c64icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF

cat > %{buildroot}%{_datadir}/applications/vice-x64dtv.desktop << EOF
[Desktop Entry]
Name=C64dtv Emulator
Comment=Commodore 64 dtv Emulator
Exec=%{_bindir}/x64dtv %U
Icon=c64icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF

cat > %{buildroot}%{_datadir}/applications/vice-x128.desktop << EOF
[Desktop Entry]
Name=C128 Emulator
Comment=Commodore 128 Emulator
Exec=%{_bindir}/x128 %U
Icon=c128icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xpet.desktop << EOF
[Desktop Entry]
Name=PET Emulator
Comment=Commodore PET Emulator
Exec=%{_bindir}/xpet %U
Icon=peticon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xvic.desktop << EOF
[Desktop Entry]
Name=VIC 20 Emulator
Comment=Commodore VIC 20 Emulator
Exec=%{_bindir}/xvic %U
Icon=vic20icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xcbm2.desktop << EOF
[Desktop Entry]
Name=CBM2 Emulator
Comment=Commodore BM 2 Emulator
Exec=%{_bindir}/xcbm2 %U
Icon=c610icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-xplus4.desktop << EOF
[Desktop Entry]
Name=CPLUS4 Emulator
Comment=Commodore PLUS4 Emulator
Exec=%{_bindir}/xplus4 %U
Icon=plus4icon
Terminal=false
Type=Application
MimeType=application/x-d64;application/x-t64;application/x-x64;
StartupNotify=true
Categories=GNOME;GTK;System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-c1541.desktop << EOF
[Desktop Entry]
Name=VICE disk image tool
Comment=C1541 stand alone disk image maintenance program
Exec=%{_bindir}/c1541 %U
Icon=commodore
Terminal=true
Type=Application
StartupNotify=true
Categories=System;Emulator;
EOF
cat > %{buildroot}%{_datadir}/applications/vice-vsid.desktop << EOF
[Desktop Entry]
Name=VSID music player
Comment=VICE SID music player for Commodore tunes
Exec=%{_bindir}/vsid %U
Icon=commodore
Terminal=false
Type=Application
StartupNotify=true
Categories=AudioVideo;Audio;Player;
MimeType=audio/prs.sid
EOF

# Install icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48}/apps
tar xjf %{SOURCE1} -C %{buildroot}%{_iconsdir}/hicolor/32x32/apps
tar xjf %{SOURCE2} -C %{buildroot}%{_iconsdir}/hicolor/48x48/apps
tar xjf %{SOURCE3} -C %{buildroot}%{_iconsdir}/hicolor/16x16/apps

%files
%doc README
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/applications/vice-*
%{_iconsdir}/hicolor/*/apps/*.png


%changelog
* Sat May 04 2024 wally <wally> 3.8-2.mga10
+ Revision: 2062176
- add patch to fix compiler flags usage

* Sat May 04 2024 barjac <barjac> 3.8-1.mga10
+ Revision: 2062103
- new version 3.8
- fix build with gcc-14
- new BR curl
- update configure options

* Sat Nov 25 2023 danf <danf> 3.7.1-2.mga10
+ Revision: 2009666
- Enable Ethernet and IEEE 1284 support

* Sun Feb 12 2023 ghibo <ghibo> 3.7.1-1.mga9
+ Revision: 1941035
- Update to release 3.7.1

* Tue Apr 05 2022 umeabot <umeabot> 3.6.1-2.mga9
+ Revision: 1844076
- Mageia 9 Mass Rebuild

* Mon Jan 31 2022 barjac <barjac> 3.6.1-1.mga9
+ Revision: 1770812
- new version 3.6.1

* Mon Jan 03 2022 barjac <barjac> 3.6.0-1.mga9
+ Revision: 1766477
- new version 3.6.0
+ danf <danf>
- Add sid MimeType to vsid desktop file

* Wed Dec 30 2020 barjac <barjac> 3.5-1.mga8
+ Revision: 1665438
- new version 3.5
- drop obsolete patches
- fix source0
- enable html docs
- tidy spec, update files lists
- add new BRs

* Wed Dec 02 2020 luigiwalser <luigiwalser> 3.4-0.37362.6.mga8
+ Revision: 1651622
- rebuild for glew

* Sat Oct 31 2020 wally <wally> 3.4-0.37362.5.mga8
+ Revision: 1640944
- fix build with autoconf > 2.69

* Sun May 17 2020 danf <danf> 3.4-0.37362.4.mga8
+ Revision: 1585193
- Disable -g on C files on aarch64 to try to work around a toolchain bug
- Fix multiple definition errors with gcc 10

* Sun Apr 26 2020 wally <wally> 3.4-0.37362.3.mga8
+ Revision: 1572263
- disable OSS support
- enable pulseaudio support
- enable lame support
- enable jpeg support

* Thu Feb 20 2020 umeabot <umeabot> 3.4-0.37362.2.mga8
+ Revision: 1545202
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 barjac <barjac> 3.4-0.37362.1.mga8
+ Revision: 1484240
- new version 3.4
- taken from master at svn -r37362
- new buildrequires added
- new emulator for C64dtv added
- locales dropped upstream
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 3.1-2.mga8
+ Revision: 1476023
- rebuild for readline

* Tue Oct 02 2018 barjac <barjac> 3.1-1.mga7
+ Revision: 1314853
- new version 3.1

* Mon Sep 03 2018 tv <tv> 2.4.33-3.mga7
+ Revision: 1256795
- rely on filetriggers for info system (mga#23482)

* Tue Jul 31 2018 wally <wally> 2.4.33-2.mga7
+ Revision: 1246435
- add patches originally from RPM Fusion
  - use xdg-open to open links
  - install (data) files to /usr/share/vice/
  - skip rpath

* Wed Dec 20 2017 barjac <barjac> 2.4.33-1.mga7
+ Revision: 1183608
- new version 2.4.33

* Sat Apr 23 2016 barjac <barjac> 2.4.27-1.mga6
+ Revision: 1005687
- new version 2.4.27

* Mon Apr 04 2016 barjac <barjac> 2.4.26-1.mga6
+ Revision: 998480
- new version 2.4.26

* Sat Jan 16 2016 barjac <barjac> 2.4.24-1.mga6
+ Revision: 924666
- new minor version 2.4.24

* Thu Jan 07 2016 luigiwalser <luigiwalser> 2.4.20-2.svn29913.mga6
+ Revision: 920411
- rebuild for giflib

* Tue Oct 06 2015 barjac <barjac> 2.4.20-1.svn29913.mga6
+ Revision: 886594
- upstream snapshot fixes -fPIC issue
- patch removed as merged upstream

* Mon Oct 05 2015 barjac <barjac> 2.4.20-1.mga6
+ Revision: 886460
- new version 2.4.20
- patched to fix build
+ danf <danf>
- Updated URL

* Wed Oct 15 2014 umeabot <umeabot> 2.4.7-3.mga5
+ Revision: 739011
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.4.7-2.mga5
+ Revision: 690201
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 barjac <barjac> 2.4.7-1.mga5
+ Revision: 674352
- new version 2.4.7

* Thu Mar 06 2014 barjac <barjac> 2.4.6-1.mga5
+ Revision: 600587
- new version 2.4.6

* Sat Oct 19 2013 umeabot <umeabot> 2.4.5-2.mga4
+ Revision: 532949
- Mageia 4 Mass Rebuild

* Sat Aug 24 2013 barjac <barjac> 2.4.5-1.mga4
+ Revision: 470408
- new version 2.4.5

* Tue Jun 04 2013 fwang <fwang> 2.4.1-3.mga4
+ Revision: 436946
- rebuild for new libpng

* Mon Jan 14 2013 umeabot <umeabot> 2.4.1-2.mga3
+ Revision: 385407
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 barjac <barjac> 2.4.1-1.mga3
+ Revision: 341352
- fix lib dir
- correct tarball perms
- new version 2.4.1
- changed BR
- changed source tarball format
+ fwang <fwang>
- update br

* Fri Oct 12 2012 barjac <barjac> 2.3.23-1.mga3
+ Revision: 304984
- new version
- removed BR ffmpeg-devel added BR vte-devel

* Sun Feb 26 2012 barjac <barjac> 2.3.14-2.mga2
+ Revision: 215272
+ rebuild (emptylog)

* Sun Feb 12 2012 barjac <barjac> 2.3.14-1.mga2
+ Revision: 207596
- New version
- Desktop files validated
- Spec cleaned
- BRs adjusted
- imported package vice


* Wed Mar 31 2010 Götz Waschk <waschk@mandriva.org> 2.2-1mdv2010.1
+ Revision: 530422
- drop all patches

  + Zombie Ryushu <ryushu@mandriva.org>
    - upgrade to 2.2
    - upgrade to 2.2

* Sun Aug 16 2009 Götz Waschk <waschk@mandriva.org> 2.1-5mdv2010.0
+ Revision: 416907
- fix build

* Fri Feb 27 2009 Emmanuel Andry <eandry@mandriva.org> 2.1-4mdv2009.1
+ Revision: 345687
- diff P1 from svn upstream to fix alsa fragment issue

* Wed Feb 25 2009 Götz Waschk <waschk@mandriva.org> 2.1-3mdv2009.1
+ Revision: 344823
- rebuild for new libreadline

* Sat Jan 17 2009 Emmanuel Andry <eandry@mandriva.org> 2.1-2mdv2009.1
+ Revision: 330795
- diff P0 to fix str fmt

  + Zombie Ryushu <ryushu@mandriva.org>
    - New version to fix XRandR Fullscreen bug

* Tue Oct 21 2008 Götz Waschk <waschk@mandriva.org> 2.0-1mdv2009.1
+ Revision: 296231
- new version
- update build deps
- update source URL

* Thu Jun 12 2008 Pixel <pixel@mandriva.com> 1.22-2mdv2009.0
+ Revision: 218426
- rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.22-2mdv2008.1
+ Revision: 136570
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Sep 06 2007 Götz Waschk <waschk@mandriva.org> 1.22-2mdv2008.0
+ Revision: 80716
- fix buildrequires

* Thu Sep 06 2007 Götz Waschk <waschk@mandriva.org> 1.22-1mdv2008.0
+ Revision: 80596
- new version
- drop patch
- fix menu category for vsid
- fix buildrequires

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 1.21-2mdv2008.0
+ Revision: 70350
- info file must be unregistered before being uninstalled

  + Götz Waschk <waschk@mandriva.org>
    - readd buildroot

* Thu Jul 26 2007 Adam Williamson <awilliamson@mandriva.org> 1.21-1mdv2008.0
+ Revision: 55710
- fd.o icons
- drop old menu
- update requires / buildrequires
- add patch0 (fixes bug caused by libx11 security update, from Debian)
- new release 1.21


* Thu Jan 18 2007 Götz Waschk <waschk@mandriva.org> 1.20-2mdv2007.0
+ Revision: 110193
- build with opencbm

* Thu Jan 18 2007 Götz Waschk <waschk@mandriva.org> 1.20-1mdv2007.1
+ Revision: 110082
- Import vice

* Thu Jan 18 2007 Götz Waschk <waschk@mandriva.org> 1.20-1mdv2007.1
- fix buildrequires
- new version
- drop patch

* Thu Jun 29 2006 Götz Waschk <waschk@mandriva.org> 1.19-2mdv2007.0
- xdg menu
- fix buildrequires

* Thu May 18 2006 Götz Waschk <waschk@mandriva.org> 1.19-1mdk
- patch for experimental gnome2 ui
- fix buildrequires
- new version

* Thu Oct 13 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.17-1mdk
- New release 1.17

* Sat May 07 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.16-2mdk
- lib64 fix
- fix ownership of icons
- %%mkrel

* Wed Feb 16 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.16-1mdk
- 1.16

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.15-3mdk
- rebuild for new readline

* Fri Nov 19 2004 Götz Waschk <waschk@linux-mandrake.com> 1.15-2mdk
- fix mime types

* Fri Oct 22 2004 Gåtz Waschk <waschk@linux-mandrake.com> 1.15-1mdk
- drop merged patch
- New release 1.15

* Fri Aug 20 2004 Gåtz Waschk <waschk@linux-mandrake.com> 1.14-4mdk
- rebuild for new menu

* Wed Aug 04 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.14-3mdk
- fix crash on 64 bit architectures (P0)
- update url

* Tue Jun 08 2004 Götz Waschk <waschk@linux-mandrake.com> 1.14-2mdk
- rebuild for new g++

* Sat May 15 2004 Michael Scherer <misc@mandrake.org> 1.14-1mdk
- New release 1.14

